{% load i18n %}

<div id="table">

  <header class="row">
    {% if search_lookups %}
      <form class="col-md-3">
        <div class="input-group">
          <input type="text" placeholder="{% trans 'Search…' %}" class="form-control" />
          <span class="input-group-btn">
            <button type="submit" class="btn btn-default">
              <i class="fa fa-search"></i>
            </button>
          </span>
        </div>
      </form>
    {% endif %}
    <div class="{% if search_lookups %}col-md-2{% else %}col-md-5{% endif %}">
      <span class="count"></span>
      <span class="spinner pull-right">
        <i class="fa fa-spinner fa-spin"></i>
      </span>

    </div>
    <nav class="col-md-7 text-right">
      <ul class="pagination pagination-sm"></ul>
    </nav>
  </header>

  <div class="table-responsive">
    <table class="table table-condensed table-striped table-bordered">
      <thead></thead>
      <tbody></tbody>
    </table>
  </div>

</div>
